Axum/Tower delivery conventions shared by local and Lambda runtimes.
Structs
- ApiFailure
- Http
Header Policy - Exact browser-request, response-exposure, and diagnostic-redaction policy.
- Http
Module - One fully state-bound Axum router contributed by a statically linked plugin.
- Http
Runtime Config - Principal
- Problem
Details - Request
Metadata
Enums
Statics
Functions
- apply_
standard_ middleware - compose_
plugin_ http - Validates and merges plugin routes, then applies Minco’s standard middleware with an automatically expanded global body ceiling.
- merge_
plugin_ http_ modules - Merges every plugin-contributed router in deterministic installation order.
- principal_
from_ headers - problem_
response - required_
header_ policy - Returns the application policy plus the exact requirements of installed HTTP modules.
- required_
request_ body_ bytes - Returns the global request-body ceiling required by all installed HTTP modules.
- validate_
plugin_ http_ modules - Verifies that HTTP contributions and plugin descriptors have an exact operation-ID correspondence.